@@ -1,5 +1,5 @@
 /*
- * Copyright 2007-2018 The jdeb developers.
+ * Copyright 2007-2019 The jdeb developers.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -503,6 +503,12 @@ public class DebMaker {
             if (packageControlFile.get("Description") == null) {
                 packageControlFile.set("Description", description);
             }
+            if (packageControlFile.get("Depends") == null) {
+                // Only add a depends entry to the control file if the field in this object has actually been set
+                if (depends != null && depends.length() > 0) {
+                    packageControlFile.set("Depends", depends);
+                }
+            }
             if (packageControlFile.get("Homepage") == null) {
                 packageControlFile.set("Homepage", homepage);
             }
