@@ -1,5 +1,5 @@
 /*
- * Copyright 2007-2018 The jdeb developers.
+ * Copyright 2007-2019 The jdeb developers.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -270,13 +270,13 @@ public class DebMojo extends AbstractMojo {
      *
      * @since 1.1
      */
-    @Parameter(defaultValue = "false")
+    @Parameter(property = "jdeb.skip", defaultValue = "false")
     private boolean skip;
 
-    @Parameter(defaultValue = "true")
+    @Parameter(property = "jdeb.skipPOMs", defaultValue = "true")
     private boolean skipPOMs;
 
-    @Parameter(defaultValue = "false")
+    @Parameter(property = "jdeb.skipSubmodules", defaultValue = "false")
     private boolean skipSubmodules;
 
     /**
